@@ -168,8 +168,6 @@ typedef struct {
 	GList *emblem;
 } EmblemLayout;
 
-#define ANTIALIAS_SELECTION_RECTANGLE TRUE
-
 static int click_policy_auto_value;
 
 /* GtkObject */
@@ -198,10 +196,6 @@ static void     draw_pixbuf                          (GdkPixbuf
 						      GdkDrawable                   *drawable,
 						      int                            x,
 						      int                            y);
-static void     draw_mask                            (GdkPixbuf                     *pixbuf,
-						      GdkDrawable                   *drawable,
-						      int                            x,
-						      int                            y);
 static PangoLayout *get_label_layout                 (PangoLayout                  **layout,
 						      NautilusIconCanvasItem        *item,
 						      const char                    *text);
@@ -213,18 +207,16 @@ static void     draw_label_layout                    (NautilusIconCanvasItem
 						      int                            x,
 						      int                            y,
 						      GdkGC                         *gc);
-
 static gboolean hit_test_stretch_handle              (NautilusIconCanvasItem        *item,
 						      ArtIRect                       canvas_rect,
 						      GtkCornerType *corner);
-static void     clear_rounded_corners                (GdkPixbuf                     *destination_pixbuf,
-						      GdkPixbuf                     *corner_pixbuf,
-						      int                            corner_size);
 static void      draw_embedded_text                  (NautilusIconCanvasItem        *icon_item,
 						      GdkDrawable                   *drawable,
 						      int                            x,
 						      int                            y);
 
+static GdkPixbuf *nautilus_icon_canvas_lighten_pixbuf (GdkPixbuf* src, guint lighten_value);
+
 
 static NautilusIconCanvasItemClass *parent_class = NULL;
 static gpointer accessible_parent_class = NULL;
@@ -366,8 +358,12 @@ nautilus_icon_canvas_item_set_property (GObject        *object,
 		g_free (details->editable_text);
 		details->editable_text = g_strdup (g_value_get_string (value));
 		if (details->text_util) {
+			AtkObject *accessible;
+
 			gail_text_util_text_setup (details->text_util,
 						   details->editable_text);
+			accessible = eel_accessibility_get_atk_object (item); 
+			g_object_notify (G_OBJECT(accessible), "accessible-name");
 		}
 		
 		nautilus_icon_canvas_item_invalidate_label_size (item);
@@ -815,57 +811,52 @@ nautilus_icon_canvas_item_update (EelCanvasItem *item,
 }
 
 /* Rendering */
-
 static gboolean
 in_single_click_mode (void)
 {
 	return click_policy_auto_value == NAUTILUS_CLICK_POLICY_SINGLE;
 }
 
-/* Multiplies each pixel in a pixbuf by the specified color */
+
+/* Utility routine to create a rectangle with rounded corners.
+ * This could possibly move to Eel as a general purpose routine. 
+ */
 static void
-multiply_pixbuf_rgba (GdkPixbuf *pixbuf, guint rgba)
+make_round_rect (cairo_t *cr,
+		 double x, 
+    		 double y, 
+		 double width, 
+		 double height,
+		 double radius)
 {
-	guchar *pixels;
-	int r, g, b, a;
-	int width, height, rowstride;
-	gboolean has_alpha;
-	int x, y;
-	guchar *p;
+	double cx, cy;
+	
+	width -= 2 * radius;
+	height -= 2 * radius;
+	
+	cairo_move_to (cr, x + radius, y);
+	
+	cairo_rel_line_to (cr, width, 0.0);
+	
+	cairo_get_current_point (cr, &cx, &cy);
+	cairo_arc (cr, cx, cy + radius, radius, 3.0 * G_PI_2, 0);
 
-	g_return_if_fail (gdk_pixbuf_get_colorspace (pixbuf) == GDK_COLORSPACE_RGB);
-	g_return_if_fail (gdk_pixbuf_get_n_channels (pixbuf) == 3
-			  || gdk_pixbuf_get_n_channels (pixbuf) == 4);
+	cairo_rel_line_to (cr, 0.0, height);
 
-	r = EEL_RGBA_COLOR_GET_R (rgba);
-	g = EEL_RGBA_COLOR_GET_G (rgba);
-	b = EEL_RGBA_COLOR_GET_B (rgba);
-	a = EEL_RGBA_COLOR_GET_A (rgba);
+	cairo_get_current_point (cr, &cx, &cy);
+	cairo_arc (cr, cx - radius, cy, radius, 0, G_PI_2);
 
-	width = gdk_pixbuf_get_width (pixbuf);
-	height = gdk_pixbuf_get_height (pixbuf);
-	rowstride = gdk_pixbuf_get_rowstride (pixbuf);
-	has_alpha = gdk_pixbuf_get_has_alpha (pixbuf);
+	cairo_rel_line_to (cr, - width, 0.0);
+	
+	cairo_get_current_point (cr, &cx, &cy);
+	cairo_arc (cr, cx, cy - radius, radius, G_PI_2, G_PI);
 
-	pixels = gdk_pixbuf_get_pixels (pixbuf);
+	cairo_rel_line_to (cr, 0.0, -height);
 
-	for (y = 0; y < height; y++) {
-		p = pixels;
+	cairo_get_current_point (cr, &cx, &cy);
+	cairo_arc (cr, cx + radius, cy, radius, G_PI, 3.0 * G_PI_2);
 
-		for (x = 0; x < width; x++) {
-			p[0] = p[0] * r / 255;
-			p[1] = p[1] * g / 255;
-			p[2] = p[2] * b / 255;
-
-			if (has_alpha) {
-				p[3] = p[3] * a / 255;
-				p += 4;
-			} else
-				p += 3;
-		}
-
-		pixels += rowstride;
-	}
+	cairo_close_path (cr);
 }
 
 static void
@@ -878,39 +869,38 @@ draw_frame (NautilusIconCanvasItem *item,
 	    int width,
 	    int height)
 {
-	GdkPixbuf *selection_pixbuf;
 	NautilusIconContainer *container;
+	cairo_t *cr;
+	GdkColor background_color_gdk;
 
 	container = NAUTILUS_ICON_CONTAINER (EEL_CANVAS_ITEM (item)->canvas);
 
-	if (ANTIALIAS_SELECTION_RECTANGLE) {
-		selection_pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB,
-						   TRUE,
-						   8,
-						   width,
-						   height);
-		eel_gdk_pixbuf_fill_rectangle_with_color (selection_pixbuf,
-							  eel_gdk_pixbuf_whole_pixbuf,
-							  0xffffffff);
-		if (container->details->highlight_frame != NULL) {
-			clear_rounded_corners (selection_pixbuf,
-					       container->details->highlight_frame,
-					       5);
-		}
-		multiply_pixbuf_rgba (selection_pixbuf,
-				      color);
-		if (create_mask) {
-			draw_mask (selection_pixbuf, drawable, x, y);
-		} else {
-			draw_pixbuf (selection_pixbuf, drawable, x, y);
-		}
-		g_object_unref (selection_pixbuf);
-	} else {
-		gdk_draw_rectangle
-			(drawable, 
-			 GTK_WIDGET (container)->style->black_gc, TRUE,
-			 x, y, width, height);
+	/* Get a cairo context */
+	cr = gdk_cairo_create (drawable);	
+	
+	/* Set the rounded rect clip region. Magic rounding value taken
+	 * from old code. 
+	 */
+	make_round_rect (cr, x, y, width, height, 5);
+	
+	/* Get the GdkColor for the label selection fill */
+	background_color_gdk = eel_gdk_rgb_to_color (color);
+	
+	if (create_mask) {
+		/* Dunno how to do this with cairo...
+		 * It used to threshold the rendering so that the
+		 * bitmask didn't show white where alpha < 0.5
+		 */
 	}
+	
+	/* Set the label background color */	        	
+	gdk_cairo_set_source_color (cr, &background_color_gdk);
+	
+	/* Paint into drawable now that we have set up the color and opacity */	
+	cairo_fill (cr);
+	
+	/* Clean up now that drawing is complete */
+	cairo_destroy (cr);		 
 }
 
 /* Keep these for a bit while we work on performance of draw_or_measure_label_text. */
@@ -955,7 +945,7 @@ draw_or_measure_label_text (NautilusIconCanvasItem *item,
 	PangoLayout *additional_layout;
 	GdkColor *label_color;
 	int icon_width;
-	gboolean have_editable, have_additional, needs_highlight, needs_frame;
+	gboolean have_editable, have_additional, needs_highlight, needs_frame, prelight_label;
 	int max_text_width;
 	int x;
 	GdkGC *gc;
@@ -1042,16 +1032,10 @@ draw_or_measure_label_text (NautilusIconCanvasItem *item,
 		details->text_height = editable_height;
 	}
 
-	if (ANTIALIAS_SELECTION_RECTANGLE) {
-		/* add some extra space for highlighting even when we don't highlight so things won't move */
-		text_back_padding_x = 4;
-		text_back_padding_y = 1;
-	} else {
-		/* add slop used for highlighting, even if we're not highlighting now */
-		text_back_padding_x = 2;
-		text_back_padding_y = 0;
-	}
-
+	/* add some extra space for highlighting even when we don't highlight so things won't move */
+	text_back_padding_x = 4;
+	text_back_padding_y = 1;
+	
 	details->text_height += text_back_padding_y*2; /* extra slop for nicer highlighting */
 	details->text_width += text_back_padding_x*2;  /* extra to make it look nicer */
 
@@ -1069,7 +1053,7 @@ draw_or_measure_label_text (NautilusIconCanvasItem *item,
 	}
 
 	text_rect = compute_text_rectangle (item, icon_rect, TRUE);
-	
+
 	/* if the icon is highlighted, do some set-up */
 	if (needs_highlight && !details->is_renaming &&
 	    details->text_width > 0 && details->text_height > 0) {
@@ -1083,7 +1067,6 @@ draw_or_measure_label_text (NautilusIconCanvasItem *item,
 			    text_rect.y1 - text_rect.y0);
 	}
 
-		
 	if (container->details->label_position == NAUTILUS_ICON_LABEL_POSITION_BESIDE) {
 		x = text_rect.x0 + 2;
 	} else {
@@ -1093,21 +1076,34 @@ draw_or_measure_label_text (NautilusIconCanvasItem *item,
 	if (have_editable) {
 		gtk_widget_style_get (GTK_WIDGET (container),
 				      "frame_text", &needs_frame,
+				      "activate_prelight_icon_label", &prelight_label,
 				      NULL);
 		if (needs_frame && !needs_highlight && details->text_width > 0 && details->text_height > 0) {
-			draw_frame (item, 
-				    drawable,
-				    container->details->normal_color_rgba,
-				    create_mask,
-				    text_rect.x0,
-				    text_rect.y0,
-				    text_rect.x1 - text_rect.x0,
-				    text_rect.y1 - text_rect.y0);
+			if (!(prelight_label && item->details->is_prelit)) {
+				draw_frame (item, 
+					    drawable,
+					    container->details->normal_color_rgba,
+					    create_mask,
+					    text_rect.x0,
+					    text_rect.y0,
+					    text_rect.x1 - text_rect.x0,
+					    text_rect.y1 - text_rect.y0);
+			} else {
+				draw_frame (item, 
+					    drawable,
+					    container->details->prelight_color_rgba,
+					    create_mask,
+					    text_rect.x0,
+					    text_rect.y0,
+					    text_rect.x1 - text_rect.x0,
+					    text_rect.y1 - text_rect.y0);
+			}
 		}
 		
 		gc = nautilus_icon_container_get_label_color_and_gc
 			(NAUTILUS_ICON_CONTAINER (canvas_item->canvas),
-			 &label_color, TRUE, needs_highlight);
+			 &label_color, TRUE, needs_highlight,
+			 prelight_label & item->details->is_prelit);
 
 		draw_label_layout (item, drawable,
 				   editable_layout, needs_highlight,
@@ -1119,7 +1115,8 @@ draw_or_measure_label_text (NautilusIconCanvasItem *item,
 	if (have_additional) {
 		gc = nautilus_icon_container_get_label_color_and_gc
 			(NAUTILUS_ICON_CONTAINER (canvas_item->canvas),
-			 &label_color, FALSE, needs_highlight);
+			 &label_color, FALSE, needs_highlight,
+			 FALSE);
 		
 		draw_label_layout (item, drawable,
 				   additional_layout, needs_highlight,
@@ -1429,14 +1426,110 @@ draw_pixbuf (GdkPixbuf *pixbuf, GdkDrawable *drawable, int x, int y)
 			 GDK_RGB_DITHER_NORMAL, 0, 0);
 }
 
-static void
-draw_mask (GdkPixbuf *pixbuf, GdkDrawable *drawable, int x, int y)
+/* should be moved to libeel! */
+static guchar
+nautilus_icon_canvas_lighten_pixbuf_component (guchar cur_value, guint lighten_value) {
+	int new_value = cur_value;
+	if (lighten_value > 0) {
+		new_value += lighten_value + (new_value >> 3);
+		if (new_value > 255) {
+			new_value = 255;
+		}
+	}
+	return (guchar) new_value;
+}
+
+/* should be moved to libeel! */
+static GdkPixbuf *
+nautilus_icon_canvas_lighten_pixbuf (GdkPixbuf* src, guint lighten_value) {
+	GdkPixbuf *dest;
+	int i, j;
+	int width, height, has_alpha, src_row_stride, dst_row_stride;
+	guchar *target_pixels, *original_pixels;
+	guchar *pixsrc, *pixdest;
+
+	g_return_val_if_fail (gdk_pixbuf_get_colorspace (src) == GDK_COLORSPACE_RGB, NULL);
+	g_return_val_if_fail ((!gdk_pixbuf_get_has_alpha (src)
+			       && gdk_pixbuf_get_n_channels (src) == 3)
+			      || (gdk_pixbuf_get_has_alpha (src)
+				  && gdk_pixbuf_get_n_channels (src) == 4), NULL);
+	g_return_val_if_fail (gdk_pixbuf_get_bits_per_sample (src) == 8, NULL);
+
+	dest = gdk_pixbuf_new (gdk_pixbuf_get_colorspace (src),
+			       gdk_pixbuf_get_has_alpha (src),
+			       gdk_pixbuf_get_bits_per_sample (src),
+			       gdk_pixbuf_get_width (src),
+			       gdk_pixbuf_get_height (src));
+	
+	has_alpha = gdk_pixbuf_get_has_alpha (src);
+	width = gdk_pixbuf_get_width (src);
+	height = gdk_pixbuf_get_height (src);
+	dst_row_stride = gdk_pixbuf_get_rowstride (dest);
+	src_row_stride = gdk_pixbuf_get_rowstride (src);
+	target_pixels = gdk_pixbuf_get_pixels (dest);
+	original_pixels = gdk_pixbuf_get_pixels (src);
+
+	for (i = 0; i < height; i++) {
+		pixdest = target_pixels + i * dst_row_stride;
+		pixsrc = original_pixels + i * src_row_stride;
+		for (j = 0; j < width; j++) {		
+			*pixdest++ = nautilus_icon_canvas_lighten_pixbuf_component (*pixsrc++, lighten_value);
+			*pixdest++ = nautilus_icon_canvas_lighten_pixbuf_component (*pixsrc++, lighten_value);
+			*pixdest++ = nautilus_icon_canvas_lighten_pixbuf_component (*pixsrc++, lighten_value);
+			if (has_alpha) {
+				*pixdest++ = *pixsrc++;
+			}
+		}
+	}
+	return dest;
+}
+
+
+
+static GdkPixbuf *
+render_icon (GdkPixbuf *pixbuf, guint render_mode, guint saturation, guint brightness, guint lighten_value, guint color)
 {
-	gdk_pixbuf_render_threshold_alpha (pixbuf, drawable,
-					   0, 0, x, y,
-					   gdk_pixbuf_get_width (pixbuf),
-					   gdk_pixbuf_get_height (pixbuf),
-					   128);
+ 	GdkPixbuf *temp_pixbuf, *old_pixbuf;
+
+	if (render_mode == 1) {
+	/* lighten icon */
+		temp_pixbuf = eel_create_spotlight_pixbuf (pixbuf);
+	}
+	else if (render_mode == 2) {
+	/* colorize icon */
+		temp_pixbuf = eel_create_colorized_pixbuf (pixbuf,
+				   EEL_RGBA_COLOR_GET_R (color),
+				   EEL_RGBA_COLOR_GET_G (color),
+				   EEL_RGBA_COLOR_GET_B (color));
+	} else if (render_mode == 3) {
+	/* monochromely colorize icon */
+		old_pixbuf = eel_create_darkened_pixbuf (pixbuf, 0, 255);		
+		temp_pixbuf = eel_create_colorized_pixbuf (old_pixbuf,
+				   EEL_RGBA_COLOR_GET_R (color),
+				   EEL_RGBA_COLOR_GET_G (color),
+				   EEL_RGBA_COLOR_GET_B (color));
+		g_object_unref (old_pixbuf);
+	} else {
+		temp_pixbuf = NULL;
+	}
+
+	if (saturation < 255 || brightness < 255 || temp_pixbuf == NULL) { // temp_pixbuf == NULL just for safer code (return copy)
+		old_pixbuf = temp_pixbuf;
+		temp_pixbuf = eel_create_darkened_pixbuf (temp_pixbuf ? temp_pixbuf : pixbuf, saturation, brightness);
+		if (old_pixbuf) {
+			g_object_unref (old_pixbuf);
+		}
+	}
+
+	if (lighten_value > 0) {
+		old_pixbuf = temp_pixbuf;
+  		temp_pixbuf = nautilus_icon_canvas_lighten_pixbuf (temp_pixbuf ? temp_pixbuf : pixbuf, lighten_value);
+		if (old_pixbuf) {
+			g_object_unref (old_pixbuf);
+		}
+	}
+
+	return temp_pixbuf;
 }
 
 /* shared code to highlight or dim the passed-in pixbuf */
@@ -1445,18 +1538,38 @@ real_map_pixbuf (NautilusIconCanvasItem *icon_item)
 {
 	EelCanvas *canvas;
 	char *audio_filename;
+	NautilusIconContainer *container;
 	GdkPixbuf *temp_pixbuf, *old_pixbuf, *audio_pixbuf;
 	double zoom;
+	guint render_mode, saturation, brightness, lighten;
 	
 	temp_pixbuf = icon_item->details->pixbuf;
 	canvas = EEL_CANVAS_ITEM(icon_item)->canvas;
+	container = NAUTILUS_ICON_CONTAINER (canvas);
 
 	g_object_ref (temp_pixbuf);
 
 	if (icon_item->details->is_prelit) {
 		old_pixbuf = temp_pixbuf;
-		temp_pixbuf = eel_create_spotlight_pixbuf (temp_pixbuf);
-		g_object_unref (old_pixbuf);
+
+		gtk_widget_style_get (GTK_WIDGET (container),
+			      "prelight_icon_render_mode", &render_mode,
+			      "prelight_icon_saturation", &saturation,
+			      "prelight_icon_brightness", &brightness,
+			      "prelight_icon_lighten", &lighten,
+			      NULL);
+
+		if (render_mode > 0 || saturation < 255 || brightness < 255) {
+			temp_pixbuf = render_icon (temp_pixbuf,
+				render_mode,
+				saturation,
+				brightness,
+				lighten,
+				container->details->prelight_icon_color_rgba);
+			g_object_unref (old_pixbuf);
+       	}
+
+
 
 		/* FIXME bugzilla.gnome.org 42471: This hard-wired image is inappropriate to
 		 * this level of code, which shouldn't know that the
@@ -1508,12 +1621,36 @@ real_map_pixbuf (NautilusIconCanvasItem *icon_item)
 
 		temp_pixbuf = eel_create_colorized_pixbuf (temp_pixbuf,
 							   EEL_RGBA_COLOR_GET_R (color),
-							   EEL_RGBA_COLOR_GET_G(color),
+							   EEL_RGBA_COLOR_GET_G (color),
 							   EEL_RGBA_COLOR_GET_B (color));
 							   
 		g_object_unref (old_pixbuf);
 	} 
 
+	if (!icon_item->details->is_active
+			&& !icon_item->details->is_prelit
+			&& !icon_item->details->is_highlighted_for_selection
+			&& !icon_item->details->is_highlighted_for_drop) {
+		old_pixbuf = temp_pixbuf;
+
+		gtk_widget_style_get (GTK_WIDGET (container),
+			      "normal_icon_render_mode", &render_mode,
+			      "normal_icon_saturation", &saturation,
+			      "normal_icon_brightness", &brightness,
+			      "normal_icon_lighten", &lighten,
+			      NULL);
+		if (render_mode > 0 || saturation < 255 || brightness < 255) {
+			/* if theme requests colorization */
+			temp_pixbuf = render_icon (temp_pixbuf,
+					    render_mode,
+					    saturation,
+					    brightness,
+					    lighten,
+					    container->details->normal_icon_color_rgba);
+			g_object_unref (old_pixbuf);
+		}
+	}
+	
 	return temp_pixbuf;
 }
 
@@ -1616,6 +1753,7 @@ nautilus_icon_canvas_item_draw (EelCanvasItem *item, GdkDrawable *drawable,
 	icon_rect = icon_item->details->canvas_rect;
 	
 	/* if the pre-lit or selection flag is set, make a pre-lit or darkened pixbuf and draw that instead */
+	/* and colorize normal pixbuf if rc wants that */
 	temp_pixbuf = map_pixbuf (icon_item);
 	pixbuf_rect.x = icon_rect.x0;
 	pixbuf_rect.y = icon_rect.y0;
@@ -1783,48 +1921,6 @@ draw_label_layout (NautilusIconCanvasItem *item,
 	}
 }
 
-/* clear the corners of the selection pixbuf by copying the corners of the passed-in pixbuf */
-static void
-clear_rounded_corners (GdkPixbuf *destination_pixbuf, GdkPixbuf *corner_pixbuf, int corner_size)
-{
-	int dest_width, dest_height, src_width, src_height;
-		
-	dest_width = gdk_pixbuf_get_width (destination_pixbuf);
-	dest_height = gdk_pixbuf_get_height (destination_pixbuf);
-	
-	src_width = gdk_pixbuf_get_width (corner_pixbuf);
-	src_height = gdk_pixbuf_get_height (corner_pixbuf);
-	
-	/* draw top left corner */
-	gdk_pixbuf_copy_area (corner_pixbuf,
-			      0, 0,
-			      corner_size, corner_size,
-			      destination_pixbuf,
-			      0, 0);
-	
-	/* draw top right corner */
-	gdk_pixbuf_copy_area (corner_pixbuf,
-			      src_width - corner_size, 0,
-			      corner_size, corner_size,
-			      destination_pixbuf,
-			      dest_width - corner_size, 0);
-
-	/* draw bottom left corner */
-	gdk_pixbuf_copy_area (corner_pixbuf,
-			      0, src_height - corner_size,
-			      corner_size, corner_size,
-			      destination_pixbuf,
-			      0, dest_height - corner_size);
-	
-	/* draw bottom right corner */
-	gdk_pixbuf_copy_area (corner_pixbuf,
-			      src_width - corner_size, src_height - corner_size,
-			      corner_size, corner_size,
-			      destination_pixbuf,
-			      dest_width - corner_size, dest_height - corner_size);
-}
-
-
 /* handle events */
 
 static int
