@@ -54,6 +54,7 @@
 #include <libnautilus-extension/nautilus-column-provider.h>
 #include <libnautilus-private/nautilus-column-chooser.h>
 #include <libnautilus-private/nautilus-column-utilities.h>
+#include <libnautilus-private/nautilus-debug-log.h>
 #include <libnautilus-private/nautilus-directory-background.h>
 #include <libnautilus-private/nautilus-dnd.h>
 #include <libnautilus-private/nautilus-file-dnd.h>
@@ -785,6 +786,15 @@ row_expanded_callback (GtkTreeView *treeview, GtkTreeIter *iter, GtkTreePath *pa
 	view = FM_LIST_VIEW (callback_data);
 
 	if (fm_list_model_load_subdirectory (view->details->model, path, &directory)) {
+		char *uri;
+
+		uri = nautilus_directory_get_uri (directory);
+		nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
+				    "list view row expanded window=%p: %s",
+				    fm_directory_view_get_containing_window (FM_DIRECTORY_VIEW (view)),
+				    uri);
+		g_free (uri);
+
 		fm_directory_view_add_subdirectory (FM_DIRECTORY_VIEW (view), directory);
 		
 		if (nautilus_directory_are_all_files_seen (directory)) {
@@ -848,6 +858,7 @@ row_collapsed_callback (GtkTreeView *treeview, GtkTreeIter *iter, GtkTreePath *p
 	GtkTreeIter parent;
 	struct UnloadDelayData *unload_data;
 	GtkTreeModel *model;
+	char *uri;
 	
 	view = FM_LIST_VIEW (callback_data);
 	model = GTK_TREE_MODEL (view->details->model);
@@ -863,6 +874,14 @@ row_collapsed_callback (GtkTreeView *treeview, GtkTreeIter *iter, GtkTreePath *p
 				    -1);
 	}
 	
+
+	uri = nautilus_file_get_uri (file);
+	nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
+			    "list view row collapsed window=%p: %s",
+			    fm_directory_view_get_containing_window (FM_DIRECTORY_VIEW (view)),
+			    uri);
+	g_free (uri);
+
 	unload_data = g_new (struct UnloadDelayData, 1);
 	unload_data->view = view;
 	unload_data->file = file;
@@ -949,6 +968,36 @@ key_press_callback (GtkWidget *widget, GdkEventKey *event, gpointer callback_dat
 	return handled;
 }
 
+static void
+fm_list_view_reveal_selection (FMDirectoryView *view)
+{
+	GList *selection;
+
+	g_return_if_fail (FM_IS_LIST_VIEW (view));
+
+        selection = fm_directory_view_get_selection (view);
+
+	/* Make sure at least one of the selected items is scrolled into view */
+	if (selection != NULL) {
+		FMListView *list_view;
+		NautilusFile *file;
+		GtkTreeIter iter;
+		GtkTreePath *path;
+		
+		list_view = FM_LIST_VIEW (view);
+		file = selection->data;
+		if (fm_list_model_get_first_iter_for_file (list_view->details->model, file, &iter)) {
+			path = gtk_tree_model_get_path (GTK_TREE_MODEL (list_view->details->model), &iter);
+
+			gtk_tree_view_scroll_to_cell (list_view->details->tree_view, path, NULL, FALSE, 0.0, 0.0);
+			
+			gtk_tree_path_free (path);
+		}
+	}
+
+        nautilus_file_list_free (selection);
+}
+
 static void
 sort_column_changed_callback (GtkTreeSortable *sortable, 
 			      FMListView *view)
@@ -975,6 +1024,9 @@ sort_column_changed_callback (GtkTreeSortable *sortable,
 	reversed_attr = (reversed ? "true" : "false");
 	nautilus_file_set_metadata (file, NAUTILUS_METADATA_KEY_LIST_VIEW_SORT_REVERSED,
 				    default_reversed_attr, reversed_attr);
+				    
+	/* Make sure selected item(s) is visible after sort */
+	fm_list_view_reveal_selection (FM_DIRECTORY_VIEW (view));							      
 }
 
 static void
@@ -1463,7 +1515,7 @@ set_sort_order_from_metadata_and_preferences (FMListView *list_view)
 
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (list_view->details->model),
 					      sort_column_id,
-					      sort_reversed ? GTK_SORT_DESCENDING : GTK_SORT_ASCENDING);
+					      sort_reversed ? GTK_SORT_DESCENDING : GTK_SORT_ASCENDING);					      
 }
 
 static gboolean
@@ -1817,36 +1869,6 @@ fm_list_view_select_all (FMDirectoryView *view)
 	gtk_tree_selection_select_all (gtk_tree_view_get_selection (FM_LIST_VIEW (view)->details->tree_view));
 }
 
-static void
-fm_list_view_reveal_selection (FMDirectoryView *view)
-{
-	GList *selection;
-
-	g_return_if_fail (FM_IS_LIST_VIEW (view));
-
-        selection = fm_directory_view_get_selection (view);
-
-	/* Make sure at least one of the selected items is scrolled into view */
-	if (selection != NULL) {
-		FMListView *list_view;
-		NautilusFile *file;
-		GtkTreeIter iter;
-		GtkTreePath *path;
-		
-		list_view = FM_LIST_VIEW (view);
-		file = selection->data;
-		if (fm_list_model_get_first_iter_for_file (list_view->details->model, file, &iter)) {
-			path = gtk_tree_model_get_path (GTK_TREE_MODEL (list_view->details->model), &iter);
-
-			gtk_tree_view_scroll_to_cell (list_view->details->tree_view, path, NULL, FALSE, 0.0, 0.0);
-			
-			gtk_tree_path_free (path);
-		}
-	}
-
-        nautilus_file_list_free (selection);
-}
-
 static void
 column_editor_response_callback (GtkWidget *dialog, 
 				 int response_id,
