@@ -53,6 +53,7 @@
 #include "nautilus-window-bookmarks.h"
 #include "nautilus-window-private.h"
 #include "nautilus-window-manage-views.h"
+#include <libxml/xmlsave.h>
 #include <glib/gstdio.h>
 #include <bonobo/bonobo-main.h>
 #include <bonobo/bonobo-object.h>
@@ -76,6 +77,7 @@
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomevfs/gnome-vfs-volume-monitor.h>
+#include <libnautilus-private/nautilus-debug-log.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-icon-factory.h>
@@ -1140,6 +1142,10 @@ nautilus_application_present_spatial_window_with_selection (NautilusApplication
 			if (new_selection) {
 				nautilus_view_set_selection (existing_window->content_view, new_selection);
 			}
+
+			nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
+					    "present EXISTING spatial window=%p: %s",
+					    existing_window, location);
 			return existing_window;
 		}
 	}
@@ -1177,6 +1183,10 @@ nautilus_application_present_spatial_window_with_selection (NautilusApplication
 			   spatial_window_destroyed_callback, NULL);
 	
 	nautilus_window_go_to_with_selection (window, location, new_selection);
+
+	nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
+			    "present NEW spatial window=%p: %s",
+			    window, location);
 	
 	return window;
 }
@@ -1239,6 +1249,10 @@ nautilus_application_create_navigation_window (NautilusApplication *application,
 	}
 	g_free (geometry_string);
 
+	nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
+			    "create new navigation window=%p",
+			    window);
+
 	return window;
 }
 
@@ -1371,6 +1385,8 @@ save_session_to_file (void)
 	GList *l;
 	char *dir, *filename;
 	unsigned n_processed;
+	int fd;
+	xmlSaveCtxtPtr ctx;
 
 	doc = xmlNewDoc ("1.0");
 
@@ -1438,16 +1454,27 @@ save_session_to_file (void)
 	}
 
 	dir = nautilus_get_user_directory ();
-	filename = tempnam (dir, "saved-session-");
+	filename = g_build_filename (dir, "saved-session-XXXXXX", NULL);
 	g_free (dir);
 
+	fd = g_mkstemp (filename);
+	if (fd < 0) {
+		g_message ("failed to open session file %s", filename);
+		g_free (filename);
+		filename = NULL;
+		goto out;
+	}
+
 	xmlIndentTreeOutput = 1;
-	if (filename == NULL || xmlSaveFormatFile (filename, doc, 1) < 0) {
+	ctx = xmlSaveToFd (fd, NULL, XML_SAVE_FORMAT);
+	if (xmlSaveDoc (ctx, doc) < 0 ||
+	    xmlSaveFlush (ctx) < 0) {
 		g_message ("failed to save session to %s", filename);
 		g_free (filename);
 		filename = NULL;
 	}
 
+ out:
 	xmlFreeDoc (doc);
 
 	return filename;
