@@ -46,7 +46,8 @@ struct _NautilusConnectServerDialogClass {
 };
 
 GType      nautilus_connect_server_dialog_get_type (void);
-GtkWidget* nautilus_connect_server_dialog_new      (NautilusWindow *window);
+GtkWidget* nautilus_connect_server_dialog_new      (NautilusWindow *window, 
+						    const gchar *uri);
 
 /* Private internal calls */
 
